@@ -40,14 +40,14 @@ extract.breakpoints <- function(rearr.ori,type=c("atfw","atrev","gcfw","gcrev"),
 
     i=0
     while(i<gridsize){
-     
-      initpsi=runif(nbreaks[which(type==t)],min=min(x.breaks),max=max(x.breaks))
+      border=(max(x.breaks)-min(x.breaks))*0.05
+      initpsi = runif(nbreaks[which(type == t)], min = (min(x.breaks)+border),max = (max(x.breaks)- border))
       if(exists("seg")){
         rm(seg)
       }
 
-      try(seg <- segmented::segmented(lm(y.breaks~x.breaks),x.breaks,psi=initpsi,it.max=it.max), silent = TRUE)
-
+      #try(seg <- segmented::segmented(lm(y.breaks~x.breaks),x.breaks,psi=initpsi,it.max=it.max), silent = TRUE)
+      try(seg <- segmented::segmented(lm(y.breaks~ x.breaks),~x.breaks, psi = initpsi, it.max = it.max), silent = TRUE)
       
       if(exists("seg")){
         starts[[length(starts)+1]]=initpsi
@@ -63,8 +63,8 @@ extract.breakpoints <- function(rearr.ori,type=c("atfw","atrev","gcfw","gcrev"),
     
     starts=starts[[wmin]]
     
-    seg=seg <- segmented::segmented(lm(y.breaks~x.breaks),x.breaks,psi=starts,it.max=it.max)
-    
+    #seg=seg <- segmented::segmented(lm(y.breaks~x.breaks),x.breaks,psi=starts,it.max=it.max)
+    seg = seg <- segmented::segmented(lm(y.breaks~ x.breaks),~x.breaks, psi = starts, it.max = it.max)
     breaks=round(seg$psi[,2])
     
     breaks=breaks[order(breaks)]
